argv library
This is a sample arg parser for building CLI application.
Note: This is very sample and is implemented only for another package (mosaic) So i suggest to avoid using this library in production cause it is still in early development.
Classes
- Argv
- This class is the main core of argv library.
- ArgvResult
- Contains the parsed results from command-line arguments.
- Flag
- Flag class represents boolean command-line arguments.
- Option
- Option class represents the classic options in the CLI.
Typedefs
-
ArgvCallback
= FutureOr<
void> Function(ArgvResult) - Callback function that will be attached on a command
Exceptions / Errors
- ArgvException
- Exception thrown when argument parsing or validation fails.